﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;
using Image = System.Drawing.Image;


namespace BarChart3D
{
	public partial class MainForm : Form
	{
		Image bgImage;

		public MainForm()
		{
			InitializeComponent();

			barChart.Title = "Agricultural produce by type";

			// create sample data
			barChart.Series = GetSeriesCollection();

			
			// set one color per series
			barChart.Theme.CommonSeriesFills = barChart.Theme.CommonSeriesStrokes = new List<Brush> {
				new SolidBrush(Color.FromArgb(102, 154, 204)),
				new SolidBrush(Color.FromArgb(0, 52, 102)),
				new SolidBrush(Color.FromArgb(206, 0, 0))
			};

			// background
			barChart.BackColor = Color.WhiteSmoke;
			barChart.PlotImage = bgImage = Properties.Resources.bgimage;
			barChart.PlotImageAlign = ImageAlign.MiddleLeft;
			barChart.PlotImageAutoSize = false;

			// axis appearance
			barChart.XAxis.Title = "";
			barChart.YAxis.Title = "Quantity in tons";
			barChart.Theme.AxisStroke = barChart.Theme.AxisLabelsBrush = new SolidBrush(Color.DimGray);
			barChart.Theme.AxisStrokeThickness = 1;

			// legend appearance
			barChart.LegendTitle = "Agricultural type";
			barChart.Theme.LegendBackground = new SolidBrush(Color.FromArgb(180, 180, 180));
			barChart.Theme.LegendBorderStroke = new SolidBrush(Color.DimGray);
			barChart.Theme.DataLabelsBrush = new SolidBrush(Color.White);
			barChart.Theme.LegendTitleBrush = new SolidBrush(Color.White);
			barChart.Theme.LegendBorderStrokeThickness = 1;
			barChart.LegendMargin = new Margins(80, 5, 5, 5);

			barChart.LayoutPanel.Margin = new Margins(10);

			SetupControls();
		}

		private void SetupControls()
		{
			cbLayout.SelectedIndex = (int)barChart.BarLayout;
			cbShowScatter.Checked = barChart.ShowScatter;
			cbImage.Checked = true;
			cbShowX.Checked = barChart.ShowXCoordinates;
			cbShowY.Checked = barChart.ShowYCoordinates;
			cbShowXTicks.Checked = barChart.ShowXTicks;
			cbShowYTicks.Checked = barChart.ShowYTicks;
			cbAllowPan.Checked = barChart.AllowPan;
			cbMoveLegend.Checked = barChart.AllowMoveLegend;
			cbHorAlign.SelectedIndex = (int)barChart.LegendHorizontalAlignment;
			cbVertAlign.SelectedIndex = (int)barChart.LegendVerticalAlignment;
			cbZoom.Checked = barChart.AllowZoom;
			tbMarginLeft.Minimum = 0;
			tbMarginLeft.Maximum = barChart.Width - 100;
			tbMarginLeft.Value = (int)barChart.LegendMargin.Left;
			tbMarginTop.Minimum = 0;
			tbMarginTop.Maximum = barChart.Height - 100;
			tbMarginTop.Value = (int)barChart.LegendMargin.Top;
		}

		private ObservableCollection<Series> GetSeriesCollection()
		{
			var labels = new string[4] { "Tomatoes", "Cucumbers", "Peppers", "Lettuce" };
			ObservableCollection<Series> collection = new ObservableCollection<Series>();
			for (int i = 0; i < 3; i++)
			{
				if (i == 0)
				{
					collection.Add(new Series2D(new double[] { 10, 20, 30, 40 },
						new double[] { 50, 40, 50, 5 },
						labels) { Title = "Traditional" });
				}
				if (i == 1)
				{
					collection.Add(new Series2D(new double[] { 10, 20, 30, 40 },
					   new double[] { 60, 10, 20, 80 },
					   labels) { Title = "Urban" });
				}
				if (i == 2)
				{
					collection.Add(new Series2D(new double[] { 10, 20, 30, 40 },
					   new double[] { 0, 60, 0, 90 },
					   labels) { Title = "Hydroponics" });
				}
			}
			return collection;
		}

		private void cbLayout_SelectedIndexChanged(object sender, EventArgs e)
		{
			barChart.BarLayout = (BarLayout)cbLayout.SelectedIndex;
		}

		private void cbShowScatter_CheckedChanged(object sender, EventArgs e)
		{
			barChart.ShowScatter = cbShowScatter.Checked;
		}

		private void cbShowX_CheckedChanged(object sender, EventArgs e)
		{
			barChart.ShowXCoordinates = cbShowX.Checked;
		}

		private void cbShowY_CheckedChanged(object sender, EventArgs e)
		{
			barChart.ShowYCoordinates = cbShowY.Checked;
		}

		private void cbShowXTicks_CheckedChanged(object sender, EventArgs e)
		{
			barChart.ShowXTicks = cbShowXTicks.Checked;
		}

		private void cbShowYTicks_CheckedChanged(object sender, EventArgs e)
		{
			barChart.ShowYTicks = cbShowYTicks.Checked;
		}

		private void cbAllowPan_CheckedChanged(object sender, EventArgs e)
		{
			barChart.AllowPan = cbAllowPan.Checked;
		}

		private void cbMoveLegend_CheckedChanged(object sender, EventArgs e)
		{
			barChart.AllowMoveLegend = cbMoveLegend.Checked;
		}

		private void cbHorAlign_SelectedIndexChanged(object sender, EventArgs e)
		{
			barChart.LegendHorizontalAlignment = (LayoutAlignment)cbHorAlign.SelectedIndex;
		}

		private void cbVertAlign_SelectedIndexChanged(object sender, EventArgs e)
		{
			barChart.LegendVerticalAlignment = (LayoutAlignment)cbVertAlign.SelectedIndex;
		}

		private void tbMarginLeft_Scroll(object sender, EventArgs e)
		{
			barChart.LegendMargin = new Margins(tbMarginLeft.Value, barChart.LegendMargin.Top, 0, 0);
		}

		private void tbMarginTop_Scroll(object sender, EventArgs e)
		{
			barChart.LegendMargin = new Margins(barChart.LegendMargin.Left, tbMarginTop.Value, 0, 0);
		}

		private void cbZoom_CheckedChanged(object sender, EventArgs e)
		{
			barChart.AllowZoom = cbZoom.Checked;
		}

		private void btnResetZoom_Click(object sender, EventArgs e)
		{
			barChart.ResetZoom();
		}

		private void cbImage_CheckedChanged(object sender, EventArgs e)
		{
			if (cbImage.Checked)
				barChart.PlotImage = bgImage;
			else
				barChart.PlotImage = null;
		}
	}
}